##  Overview
When initiatives reach the End of Life phase, automatically break quality seals on all related applications to ensure they are reviewed and updated. By using automations for this scenario, you can:
  * Maintain data quality and governance: Ensure data quality by requiring application owners to explicitly re-evaluate their applications when supporting initiatives are completed or deprecated.
  * Automate quality seal management: Eliminate manual tracking of initiative lifecycle changes to break quality seals on related applications.
